%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Investment Judgment Advisor
%%% Programed by Jhiin Joo specifically for MAC users
%%% March 3, 2009
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function varargout = Introduction4(varargin)
% INTRODUCTION4 M-file for Introduction4.fig
%      INTRODUCTION4, by itself, creates a new INTRODUCTION4 or raises the existing
%      singleton*.
%
%      H = INTRODUCTION4 returns the handle to a new INTRODUCTION4 or the handle to
%      the existing singleton*.
%
%      INTRODUCTION4('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in INTRODUCTION4.M with the given input arguments.
%
%      INTRODUCTION4('Property','Value',...) creates a new INTRODUCTION4 or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before Introduction4_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to Introduction4_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Copyright 2002-2003 The MathWorks, Inc.

% Edit the above text to modify the response to help Introduction4

% Last Modified by GUIDE v2.5 30-Oct-2008 12:14:05

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @Introduction4_OpeningFcn, ...
                   'gui_OutputFcn',  @Introduction4_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT

global SkipIntro
global templet
global XS1 WS1 XXS1 XXL1 XXR1 XXSM1 XXSL1 XXSR1 Special
global ling1_11 ling1_12 ling1_13 ling1_14
global ling1_21 ling1_22 ling1_23 ling1_24
global ling1_31 ling1_32 ling1_33 ling1_34
global ling1_41 ling1_42 ling1_43 ling1_44
global ling1_51 ling1_52 ling1_53 ling1_54
global ling1_61 ling1_62 ling1_63 ling1_64
global rank1_1 rank1_2 rank1_3 rank1_4 rank1_5
global cen1_1 cen1_2 cen1_3 cen1_4 cen1_5
global sim1_11 sim1_12 sim1_13 sim1_14 sim1_15
global sim1_21 sim1_22 sim1_23 sim1_24 sim1_25
global sim1_31 sim1_32 sim1_33 sim1_34 sim1_35
global sim1_41 sim1_42 sim1_43 sim1_44 sim1_45
global sim1_51 sim1_52 sim1_53 sim1_54 sim1_55

global XS2 WS2 XXS2 XXL2 XXR2 XXSM2 XXSL2 XXSR2 Special
global ling2_11 ling2_12 ling2_13 ling2_14
global ling2_21 ling2_22 ling2_23 ling2_24
global ling2_31 ling2_32 ling2_33 ling2_34
global ling2_41 ling2_42 ling2_43 ling2_44
global ling2_51 ling2_52 ling2_53 ling2_54
global ling2_61 ling2_62 ling2_63 ling2_64
global rank2_1 rank2_2 rank2_3 rank2_4 rank2_5
global cen2_1 cen2_2 cen2_3 cen2_4 cen2_5
global sim2_11 sim2_12 sim2_13 sim2_14 sim2_15
global sim2_21 sim2_22 sim2_23 sim2_24 sim2_25
global sim2_31 sim2_32 sim2_33 sim2_34 sim2_35
global sim2_41 sim2_42 sim2_43 sim2_44 sim2_45
global sim2_51 sim2_52 sim2_53 sim2_54 sim2_55

global XS3 WS3 XXS3 XXL3 XXR3 XXSM3 XXSL3 XXSR3
global ling3_11 ling3_12 ling3_13 ling3_14
global ling3_21 ling3_22 ling3_23 ling3_24
global ling3_31 ling3_32 ling3_33 ling3_34
global ling3_41 ling3_42 ling3_43 ling3_44
global ling3_51 ling3_52 ling3_53 ling3_54
global ling3_61 ling3_62 ling3_63 ling3_64
global rank3_1 rank3_2 rank3_3 rank3_4 rank3_5
global cen3_1 cen3_2 cen3_3 cen3_4 cen3_5
global sim3_11 sim3_12 sim3_13 sim3_14 sim3_15
global sim3_21 sim3_22 sim3_23 sim3_24 sim3_25
global sim3_31 sim3_32 sim3_33 sim3_34 sim3_35
global sim3_41 sim3_42 sim3_43 sim3_44 sim3_45
global sim3_51 sim3_52 sim3_53 sim3_54 sim3_55

% --- Executes just before Introduction4 is made visible.
function Introduction4_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to Introduction4 (see VARARGIN)


% Choose default command line output for Introduction4
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes Introduction4 wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = Introduction4_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;




% --- Executes on button press in checkbox1.
function checkbox1_Callback(hObject, eventdata, handles)
% hObject    handle to checkbox1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of checkbox1



% --- Executes on button press in checkbox2.
function checkbox2_Callback(hObject, eventdata, handles)
% hObject    handle to checkbox2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of checkbox2



% --- Executes on button press in pushbutton1.
function pushbutton1_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
close(Introduction4);%% HOME
IJA_demo; %%Introduction;

% --- Executes on button press in pushbutton2.
function pushbutton2_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
close(Introduction4); %% BACK
Introduction3;

% --- Executes on button press in pushbutton3.
function pushbutton3_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
global SkipIntro

if SkipIntro==1
    close(Introduction4);
    Description4;
else
    close(Introduction4); %% Do evaluations yourself
    Description4;
end


% --- Executes on button press in pushbutton4.
function pushbutton4_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
global SkipIntro
global templet
global XS1 WS1 XXS1 XXL1 XXR1 XXSM1 XXSL1 XXSR1 Special
global ling1_11 ling1_12 ling1_13 ling1_14
global ling1_21 ling1_22 ling1_23 ling1_24
global ling1_31 ling1_32 ling1_33 ling1_34
global ling1_41 ling1_42 ling1_43 ling1_44
global ling1_51 ling1_52 ling1_53 ling1_54
global ling1_61 ling1_62 ling1_63 ling1_64
global rank1_1 rank1_2 rank1_3 rank1_4 rank1_5
global cen1_1 cen1_2 cen1_3 cen1_4 cen1_5
global sim1_11 sim1_12 sim1_13 sim1_14 sim1_15
global sim1_21 sim1_22 sim1_23 sim1_24 sim1_25
global sim1_31 sim1_32 sim1_33 sim1_34 sim1_35
global sim1_41 sim1_42 sim1_43 sim1_44 sim1_45
global sim1_51 sim1_52 sim1_53 sim1_54 sim1_55

global XS2 WS2 XXS2 XXL2 XXR2 XXSM2 XXSL2 XXSR2 Special
global ling2_11 ling2_12 ling2_13 ling2_14
global ling2_21 ling2_22 ling2_23 ling2_24
global ling2_31 ling2_32 ling2_33 ling2_34
global ling2_41 ling2_42 ling2_43 ling2_44
global ling2_51 ling2_52 ling2_53 ling2_54
global ling2_61 ling2_62 ling2_63 ling2_64
global rank2_1 rank2_2 rank2_3 rank2_4 rank2_5
global cen2_1 cen2_2 cen2_3 cen2_4 cen2_5
global sim2_11 sim2_12 sim2_13 sim2_14 sim2_15
global sim2_21 sim2_22 sim2_23 sim2_24 sim2_25
global sim2_31 sim2_32 sim2_33 sim2_34 sim2_35
global sim2_41 sim2_42 sim2_43 sim2_44 sim2_45
global sim2_51 sim2_52 sim2_53 sim2_54 sim2_55

global XS3 WS3 XXS3 XXL3 XXR3 XXSM3 XXSL3 XXSR3
global ling3_11 ling3_12 ling3_13 ling3_14
global ling3_21 ling3_22 ling3_23 ling3_24
global ling3_31 ling3_32 ling3_33 ling3_34
global ling3_41 ling3_42 ling3_43 ling3_44
global ling3_51 ling3_52 ling3_53 ling3_54
global ling3_61 ling3_62 ling3_63 ling3_64
global rank3_1 rank3_2 rank3_3 rank3_4 rank3_5
global cen3_1 cen3_2 cen3_3 cen3_4 cen3_5
global sim3_11 sim3_12 sim3_13 sim3_14 sim3_15
global sim3_21 sim3_22 sim3_23 sim3_24 sim3_25
global sim3_31 sim3_32 sim3_33 sim3_34 sim3_35
global sim3_41 sim3_42 sim3_43 sim3_44 sim3_45
global sim3_51 sim3_52 sim3_53 sim3_54 sim3_55

close(Introduction4); %% See the Templets
if SkipIntro==1
     msgbox('Please wait while processing....');
    templet=1; %% TEMPLETS
    ShowResults_Third;    
else
    Description3;
end




